![Logo](new_logo.png)
# CircuitQ
## Simulation and analysis of superconducting circuits

CircuitQ is an an open-source toolbox for the analysis of superconducting circuits implemented in Python. It features the automated construction of a symbolic Hamiltonian of the input circuit as well as a dynamic numerical representation of this Hamiltonian with a variable basis choice. Additional features include the estimation of the T1 lifetimes of the circuit states under various noise mechanisms. The circuit quantization procedure is applicable to circuit inputs from a large design space.

Please refer to the [documentation](https://circuitq.readthedocs.io/en/latest/) for installation instructions and a guideline for using the toolbox.

More details on physics and numerical implementation can be found on our [preprint on arXiv](http://arxiv.org/abs/2106.05342
).

CircuitQ was developed by Philipp Aumann and Tim Menke under the supervision of [William Oliver](https://equs.mit.edu/) and [Wolfgang Lechner](https://www.uibk.ac.at/th-physik/quantum-optimization/).

